#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.0.11832 on 2017-03-22.
#  2017, SMART Health IT.


import os
import io
import unittest
import json
from . import claim
from .fhirdate import FHIRDate


class ClaimTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Claim", js["resourceType"])
        return claim.Claim(js)
    
    def testClaim1(self):
        inst = self.instantiate_from("claim-example-institutional-rich.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim1(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim1(inst2)
    
    def implClaim1(self, inst):
        self.assertEqual(inst.accident.date.date, FHIRDate("2014-07-09").date)
        self.assertEqual(inst.accident.date.as_json(), "2014-07-09")
        self.assertEqual(inst.accident.locationAddress.text, "Grouse Mountain Ski Hill")
        self.assertEqual(inst.accident.type.coding[0].code, "SPT")
        self.assertEqual(inst.accident.type.coding[0].display, "Sporting Accident")
        self.assertEqual(inst.accident.type.coding[0].system, "http://hl7.org/fhir/v3/ActIncidentCode")
        self.assertEqual(inst.billablePeriod.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.billablePeriod.end.as_json(), "2014-08-16")
        self.assertEqual(inst.billablePeriod.start.date, FHIRDate("2014-08-15").date)
        self.assertEqual(inst.billablePeriod.start.as_json(), "2014-08-15")
        self.assertEqual(inst.careTeam[0].qualification.coding[0].code, "physician")
        self.assertEqual(inst.careTeam[0].qualification.coding[0].system, "http://hl7.org/fhir/provider-qualification")
        self.assertTrue(inst.careTeam[0].responsible)
        self.assertEqual(inst.careTeam[0].role.coding[0].code, "primary")
        self.assertEqual(inst.careTeam[0].role.coding[0].system, "http://hl7.org/fhir/claim-careteamrole")
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "654456")
        self.assertEqual(inst.diagnosis[0].packageCode.coding[0].code, "400")
        self.assertEqual(inst.diagnosis[0].packageCode.coding[0].display, "Head trauma - concussion")
        self.assertEqual(inst.diagnosis[0].packageCode.coding[0].system, "http://hl7.org/fhir/ex-diagnosisrelatedgroup")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.diagnosis[0].type[0].coding[0].code, "admitting")
        self.assertEqual(inst.diagnosis[0].type[0].coding[0].system, "http://hl7.org/fhir/ex-diagnosistype")
        self.assertEqual(inst.employmentImpacted.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.employmentImpacted.end.as_json(), "2014-08-16")
        self.assertEqual(inst.employmentImpacted.start.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.employmentImpacted.start.as_json(), "2014-08-16")
        self.assertEqual(inst.hospitalization.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.hospitalization.end.as_json(), "2014-08-16")
        self.assertEqual(inst.hospitalization.start.date, FHIRDate("2014-08-15").date)
        self.assertEqual(inst.hospitalization.start.as_json(), "2014-08-15")
        self.assertEqual(inst.id, "960151")
        self.assertEqual(inst.identifier[0].system, "http://happyhospital.com/claim")
        self.assertEqual(inst.identifier[0].value, "96123451")
        self.assertEqual(inst.insurance[0].businessArrangement, "BA987123")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].preAuthRef[0], "PA2014G56473")
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 125.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "exam")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://hl7.org/fhir/ex-serviceproduct")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 125.0)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.total.code, "USD")
        self.assertEqual(inst.total.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.total.value, 125.0)
        self.assertEqual(inst.type.coding[0].code, "institutional")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim2(self):
        inst = self.instantiate_from("claim-example-institutional.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim2(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim2(inst2)
    
    def implClaim2(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "654456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "960150")
        self.assertEqual(inst.identifier[0].system, "http://happyhospital.com/claim")
        self.assertEqual(inst.identifier[0].value, "9612345")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 125.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "exam")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://hl7.org/fhir/ex-serviceproduct")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 125.0)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.subType[0].coding[0].code, "emergency")
        self.assertEqual(inst.subType[0].coding[0].system, "http://hl7.org/fhir/ex-claimsubtype")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.total.code, "USD")
        self.assertEqual(inst.total.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.total.value, 125.0)
        self.assertEqual(inst.type.coding[0].code, "institutional")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim3(self):
        inst = self.instantiate_from("claim-example-oral-average.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim3(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim3(inst2)
    
    def implClaim3(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "123456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "100151")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "12346")
        self.assertEqual(inst.information[0].category.coding[0].code, "missingtooth")
        self.assertEqual(inst.information[0].category.coding[0].system, "http://hl7.org/fhir/claiminformationcategory")
        self.assertEqual(inst.information[0].code.coding[0].code, "15")
        self.assertEqual(inst.information[0].code.coding[0].system, "http://hl7.org/fhir/ex-tooth")
        self.assertEqual(inst.information[0].reason.coding[0].code, "e")
        self.assertEqual(inst.information[0].reason.coding[0].system, "http://hl7.org/fhir/missingtoothreason")
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[0].timingDate.date, FHIRDate("2012-04-07").date)
        self.assertEqual(inst.information[0].timingDate.as_json(), "2012-04-07")
        self.assertEqual(inst.information[1].category.coding[0].code, "exception")
        self.assertEqual(inst.information[1].category.coding[0].system, "http://hl7.org/fhir/claiminformationcategory")
        self.assertEqual(inst.information[1].code.coding[0].code, "student")
        self.assertEqual(inst.information[1].code.coding[0].system, "http://hl7.org/fhir/claim-exception")
        self.assertEqual(inst.information[1].sequence, 2)
        self.assertEqual(inst.information[1].valueString, "Happy Valley Community College")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "1200")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(inst.item[1].bodySite.coding[0].code, "21")
        self.assertEqual(inst.item[1].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[1].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[1].net.code, "USD")
        self.assertEqual(inst.item[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].net.value, 105.0)
        self.assertEqual(inst.item[1].sequence, 2)
        self.assertEqual(inst.item[1].service.coding[0].code, "21211")
        self.assertEqual(inst.item[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[1].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[1].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[1].subSite[0].coding[0].code, "L")
        self.assertEqual(inst.item[1].subSite[0].coding[0].system, "http://fdi.org/fhir/oralsurfacecodes")
        self.assertEqual(inst.item[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].unitPrice.value, 105.0)
        self.assertEqual(inst.item[2].bodySite.coding[0].code, "36")
        self.assertEqual(inst.item[2].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[2].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[2].detail[0].factor, 0.75)
        self.assertEqual(inst.item[2].detail[0].net.code, "USD")
        self.assertEqual(inst.item[2].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].net.value, 750.0)
        self.assertEqual(inst.item[2].detail[0].sequence, 1)
        self.assertEqual(inst.item[2].detail[0].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].detail[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].unitPrice.value, 1000.0)
        self.assertEqual(inst.item[2].detail[1].net.code, "USD")
        self.assertEqual(inst.item[2].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].net.value, 350.0)
        self.assertEqual(inst.item[2].detail[1].sequence, 2)
        self.assertEqual(inst.item[2].detail[1].service.coding[0].code, "lab")
        self.assertEqual(inst.item[2].detail[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].unitPrice.value, 350.0)
        self.assertEqual(inst.item[2].net.code, "USD")
        self.assertEqual(inst.item[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].net.value, 1100.0)
        self.assertEqual(inst.item[2].sequence, 3)
        self.assertEqual(inst.item[2].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[2].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[2].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].unitPrice.value, 1100.0)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim4(self):
        inst = self.instantiate_from("claim-example-oral-bridge.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim4(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim4(inst2)
    
    def implClaim4(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.contained[0].id, "device-bridge")
        self.assertEqual(inst.contained[1].id, "referral")
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.id, "100156")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "123466")
        self.assertEqual(inst.information[0].category.coding[0].code, "prosthesis")
        self.assertEqual(inst.information[0].category.coding[0].system, "http://hl7.org/fhir/claiminformationcategory")
        self.assertEqual(inst.information[0].code.coding[0].code, "2")
        self.assertEqual(inst.information[0].code.coding[0].display, "Maryland Bridge")
        self.assertEqual(inst.information[0].code.coding[0].system, "http://hl7.org/fhir/ex-oralprostho")
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[0].timingDate.date, FHIRDate("2001-04-07").date)
        self.assertEqual(inst.information[0].timingDate.as_json(), "2001-04-07")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].bodySite.coding[0].code, "01")
        self.assertEqual(inst.item[0].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].factor, 0.75)
        self.assertEqual(inst.item[0].informationLinkId[0], 1)
        self.assertEqual(inst.item[0].locationCodeableConcept.coding[0].code, "11")
        self.assertEqual(inst.item[0].locationCodeableConcept.coding[0].system, "http://hl7.org/fhir/ex-serviceplace")
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 1050.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "67221")
        self.assertEqual(inst.item[0].service.coding[0].display, "Maryland Bridge")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 1400.0)
        self.assertEqual(inst.item[1].bodySite.coding[0].code, "21")
        self.assertEqual(inst.item[1].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[1].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[1].locationCodeableConcept.coding[0].code, "11")
        self.assertEqual(inst.item[1].locationCodeableConcept.coding[0].system, "http://hl7.org/fhir/ex-serviceplace")
        self.assertEqual(inst.item[1].net.code, "USD")
        self.assertEqual(inst.item[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].net.value, 105.0)
        self.assertEqual(inst.item[1].sequence, 2)
        self.assertEqual(inst.item[1].service.coding[0].code, "21211")
        self.assertEqual(inst.item[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[1].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[1].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[1].subSite[0].coding[0].code, "L")
        self.assertEqual(inst.item[1].subSite[0].coding[0].system, "http://fdi.org/fhir/oralsurfacecodes")
        self.assertEqual(inst.item[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].unitPrice.value, 105.0)
        self.assertEqual(inst.item[2].bodySite.coding[0].code, "24")
        self.assertEqual(inst.item[2].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[2].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[2].detail[0].factor, 0.75)
        self.assertEqual(inst.item[2].detail[0].net.code, "USD")
        self.assertEqual(inst.item[2].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].net.value, 750.0)
        self.assertEqual(inst.item[2].detail[0].sequence, 1)
        self.assertEqual(inst.item[2].detail[0].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].detail[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].unitPrice.value, 1000.0)
        self.assertEqual(inst.item[2].detail[1].net.code, "USD")
        self.assertEqual(inst.item[2].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].net.value, 350.0)
        self.assertEqual(inst.item[2].detail[1].sequence, 2)
        self.assertEqual(inst.item[2].detail[1].service.coding[0].code, "lab")
        self.assertEqual(inst.item[2].detail[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].unitPrice.value, 350.0)
        self.assertEqual(inst.item[2].locationCodeableConcept.coding[0].code, "11")
        self.assertEqual(inst.item[2].locationCodeableConcept.coding[0].system, "http://hl7.org/fhir/ex-serviceplace")
        self.assertEqual(inst.item[2].net.code, "USD")
        self.assertEqual(inst.item[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].net.value, 1100.0)
        self.assertEqual(inst.item[2].procedureLinkId[0], 1)
        self.assertEqual(inst.item[2].sequence, 3)
        self.assertEqual(inst.item[2].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[2].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[2].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].unitPrice.value, 1100.0)
        self.assertEqual(inst.payee.type.coding[0].code, "other")
        self.assertEqual(inst.payee.type.coding[0].system, "http://hl7.org/fhir/payeetype")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.procedure[0].date.date, FHIRDate("2014-07-04").date)
        self.assertEqual(inst.procedure[0].date.as_json(), "2014-07-04")
        self.assertEqual(inst.procedure[0].procedureCodeableConcept.text, "Resection of gum to increase exposed tooth.")
        self.assertEqual(inst.procedure[0].sequence, 1)
        self.assertEqual(inst.related[0].reference.value, "CASE156746B")
        self.assertEqual(inst.related[0].relationship.coding[0].code, "associated")
        self.assertEqual(inst.related[0].relationship.coding[0].system, "http://hl7.org/fhir/ex-relatedclaimrelationship")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.total.code, "USD")
        self.assertEqual(inst.total.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.total.value, 2255.0)
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim5(self):
        inst = self.instantiate_from("claim-example-oral-contained-identifier.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim5(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim5(inst2)
    
    def implClaim5(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.contained[0].id, "patient-1")
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "123456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "100155")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "12347")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "1200")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">This example assumes a national health care scheme where patients, providers and organizations have known business identifiers.</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim6(self):
        inst = self.instantiate_from("claim-example-oral-contained.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim6(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim6(inst2)
    
    def implClaim6(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.contained[0].id, "org-insurer")
        self.assertEqual(inst.contained[1].id, "org-org")
        self.assertEqual(inst.contained[2].id, "provider-1")
        self.assertEqual(inst.contained[3].id, "patient-1")
        self.assertEqual(inst.contained[4].id, "coverage-1")
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "123456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "100152")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "12347")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "1200")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim7(self):
        inst = self.instantiate_from("claim-example-oral-identifier.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim7(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim7(inst2)
    
    def implClaim7(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "123456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "100154")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "12347")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "1200")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">This example assumes a national health care scheme where patients, providers and organizations have known business identifiers.</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim8(self):
        inst = self.instantiate_from("claim-example-oral-orthoplan.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim8(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim8(inst2)
    
    def implClaim8(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2015-03-16").date)
        self.assertEqual(inst.created.as_json(), "2015-03-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "123457")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].system, "http://hl7.org/fhir/sid/icd-10")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.fundsReserve.coding[0].code, "provider")
        self.assertEqual(inst.id, "100153")
        self.assertEqual(inst.identifier[0].system, "http://happyvalley.com/claim")
        self.assertEqual(inst.identifier[0].value, "12355")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].detail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[0].net.value, 1000.0)
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[0].service.coding[0].code, "ORTHOEXAM")
        self.assertEqual(inst.item[0].detail[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].detail[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].detail[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[0].unitPrice.value, 1000.0)
        self.assertEqual(inst.item[0].detail[1].net.code, "USD")
        self.assertEqual(inst.item[0].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[1].net.value, 1500.0)
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(inst.item[0].detail[1].service.coding[0].code, "ORTHODIAG")
        self.assertEqual(inst.item[0].detail[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].detail[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].detail[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[1].unitPrice.value, 1500.0)
        self.assertEqual(inst.item[0].detail[2].net.code, "USD")
        self.assertEqual(inst.item[0].detail[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[2].net.value, 500.0)
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(inst.item[0].detail[2].service.coding[0].code, "ORTHOINITIAL")
        self.assertEqual(inst.item[0].detail[2].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].detail[2].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].detail[2].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[2].unitPrice.value, 500.0)
        self.assertEqual(inst.item[0].detail[3].quantity.value, 24)
        self.assertEqual(inst.item[0].detail[3].sequence, 4)
        self.assertEqual(inst.item[0].detail[3].service.coding[0].code, "ORTHOMONTHS")
        self.assertEqual(inst.item[0].detail[3].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].detail[4].net.code, "USD")
        self.assertEqual(inst.item[0].detail[4].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[4].net.value, 250.0)
        self.assertEqual(inst.item[0].detail[4].quantity.value, 24)
        self.assertEqual(inst.item[0].detail[4].sequence, 5)
        self.assertEqual(inst.item[0].detail[4].service.coding[0].code, "ORTHOPERIODIC")
        self.assertEqual(inst.item[0].detail[4].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].detail[4].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].detail[4].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[4].unitPrice.value, 250.0)
        self.assertEqual(inst.item[0].diagnosisLinkId[0], 1)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 9000.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "ORTHPLAN")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2015-05-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2015-05-16")
        self.assertEqual(inst.item[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].unitPrice.value, 9000.0)
        self.assertEqual(inst.item[1].bodySite.coding[0].code, "21")
        self.assertEqual(inst.item[1].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[1].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[1].net.code, "USD")
        self.assertEqual(inst.item[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].net.value, 105.0)
        self.assertEqual(inst.item[1].sequence, 2)
        self.assertEqual(inst.item[1].service.coding[0].code, "21211")
        self.assertEqual(inst.item[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[1].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[1].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[1].subSite[0].coding[0].code, "L")
        self.assertEqual(inst.item[1].subSite[0].coding[0].system, "http://fdi.org/fhir/oralsurfacecodes")
        self.assertEqual(inst.item[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[1].unitPrice.value, 105.0)
        self.assertEqual(inst.item[2].bodySite.coding[0].code, "36")
        self.assertEqual(inst.item[2].bodySite.coding[0].system, "http://fdi.org/fhir/oraltoothcodes")
        self.assertEqual(inst.item[2].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[2].detail[0].net.code, "USD")
        self.assertEqual(inst.item[2].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].net.value, 750.0)
        self.assertEqual(inst.item[2].detail[0].sequence, 1)
        self.assertEqual(inst.item[2].detail[0].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].detail[0].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[0].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[0].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[0].unitPrice.value, 750.0)
        self.assertEqual(inst.item[2].detail[1].net.code, "USD")
        self.assertEqual(inst.item[2].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].net.value, 350.0)
        self.assertEqual(inst.item[2].detail[1].sequence, 2)
        self.assertEqual(inst.item[2].detail[1].service.coding[0].code, "lab")
        self.assertEqual(inst.item[2].detail[1].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].detail[1].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].detail[1].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].detail[1].unitPrice.value, 350.0)
        self.assertEqual(inst.item[2].net.code, "USD")
        self.assertEqual(inst.item[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].net.value, 1100.0)
        self.assertEqual(inst.item[2].sequence, 3)
        self.assertEqual(inst.item[2].service.coding[0].code, "27211")
        self.assertEqual(inst.item[2].service.coding[0].system, "http://example.org/fhir/oralservicecodes")
        self.assertEqual(inst.item[2].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[2].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.item[2].unitPrice.code, "USD")
        self.assertEqual(inst.item[2].unitPrice.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[2].unitPrice.value, 1100.0)
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "normal")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "oral")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "proposed")
    
    def testClaim9(self):
        inst = self.instantiate_from("claim-example-pharmacy-compound.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim9(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim9(inst2)
    
    def implClaim9(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "654456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "760152")
        self.assertEqual(inst.identifier[0].system, "http://happypharma.com/claim")
        self.assertEqual(inst.identifier[0].value, "7612345")
        self.assertEqual(inst.information[0].category.coding[0].code, "pharmacyrefill")
        self.assertEqual(inst.information[0].code.coding[0].code, "new")
        self.assertEqual(inst.information[0].code.coding[0].system, "http://hl7.org/fhir/pharmacy-refill")
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[1].category.coding[0].code, "pharmacyinformation")
        self.assertEqual(inst.information[1].code.coding[0].code, "refillsremaining")
        self.assertEqual(inst.information[1].code.coding[0].system, "http://hl7.org/fhir/pharmacy-information")
        self.assertEqual(inst.information[1].sequence, 2)
        self.assertEqual(inst.information[1].valueQuantity.value, 0)
        self.assertEqual(inst.information[2].category.coding[0].code, "pharmacyinformation")
        self.assertEqual(inst.information[2].code.coding[0].code, "dayssupply")
        self.assertEqual(inst.information[2].code.coding[0].system, "http://hl7.org/fhir/pharmacy-information")
        self.assertEqual(inst.information[2].sequence, 3)
        self.assertEqual(inst.information[2].valueQuantity.value, 10)
        self.assertEqual(inst.information[3].category.coding[0].code, "pharmacy")
        self.assertEqual(inst.information[3].code.coding[0].code, "capsule")
        self.assertEqual(inst.information[3].code.coding[0].system, "http://hl7.org/fhir/pharmacy-form")
        self.assertEqual(inst.information[3].sequence, 4)
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].detail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[0].net.value, 20.0)
        self.assertEqual(inst.item[0].detail[0].quantity.unit, "mg")
        self.assertEqual(inst.item[0].detail[0].quantity.value, 250)
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[0].service.coding[0].code, "44001")
        self.assertEqual(inst.item[0].detail[0].service.coding[0].display, "Acetaminophen 250mg")
        self.assertEqual(inst.item[0].detail[0].service.coding[0].system, "http://localdruglist.org")
        self.assertEqual(inst.item[0].detail[0].subDetail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[0].subDetail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[0].subDetail[0].net.value, 20.0)
        self.assertEqual(inst.item[0].detail[0].subDetail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[0].subDetail[0].service.coding[0].code, "drugcost")
        self.assertEqual(inst.item[0].detail[0].subDetail[0].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[1].net.code, "USD")
        self.assertEqual(inst.item[0].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[1].net.value, 25.0)
        self.assertEqual(inst.item[0].detail[1].quantity.unit, "mg")
        self.assertEqual(inst.item[0].detail[1].quantity.value, 50)
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(inst.item[0].detail[1].service.coding[0].code, "44035")
        self.assertEqual(inst.item[0].detail[1].service.coding[0].display, "Phenacetin 50mg")
        self.assertEqual(inst.item[0].detail[1].service.coding[0].system, "http://localdruglist.org")
        self.assertEqual(inst.item[0].detail[1].subDetail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[1].subDetail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[1].subDetail[0].net.value, 25.0)
        self.assertEqual(inst.item[0].detail[1].subDetail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[1].subDetail[0].service.coding[0].code, "drugcost")
        self.assertEqual(inst.item[0].detail[1].subDetail[0].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[2].net.code, "USD")
        self.assertEqual(inst.item[0].detail[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[2].net.value, 28.0)
        self.assertEqual(inst.item[0].detail[2].quantity.unit, "mg")
        self.assertEqual(inst.item[0].detail[2].quantity.value, 25)
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(inst.item[0].detail[2].service.coding[0].code, "44057")
        self.assertEqual(inst.item[0].detail[2].service.coding[0].display, "Codeine 25mg")
        self.assertEqual(inst.item[0].detail[2].service.coding[0].system, "http://localdruglist.org")
        self.assertEqual(inst.item[0].detail[2].subDetail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[2].subDetail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[2].subDetail[0].net.value, 28.0)
        self.assertEqual(inst.item[0].detail[2].subDetail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[2].subDetail[0].service.coding[0].code, "drugcost")
        self.assertEqual(inst.item[0].detail[2].subDetail[0].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[3].net.code, "USD")
        self.assertEqual(inst.item[0].detail[3].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[3].net.value, 22.0)
        self.assertEqual(inst.item[0].detail[3].sequence, 2)
        self.assertEqual(inst.item[0].detail[3].service.coding[0].code, "markup")
        self.assertEqual(inst.item[0].detail[3].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[4].net.code, "USD")
        self.assertEqual(inst.item[0].detail[4].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[4].net.value, 60.0)
        self.assertEqual(inst.item[0].detail[4].sequence, 3)
        self.assertEqual(inst.item[0].detail[4].service.coding[0].code, "compoundfee")
        self.assertEqual(inst.item[0].detail[4].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].informationLinkId[0], 1)
        self.assertEqual(inst.item[0].informationLinkId[1], 2)
        self.assertEqual(inst.item[0].informationLinkId[2], 3)
        self.assertEqual(inst.item[0].informationLinkId[3], 4)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 155.0)
        self.assertEqual(inst.item[0].quantity.code, "TAB")
        self.assertEqual(inst.item[0].quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.item[0].quantity.unit, "TAB")
        self.assertEqual(inst.item[0].quantity.value, 30)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "compound")
        self.assertEqual(inst.item[0].service.coding[0].display, "Custom compound")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://localdruglist.org")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "stat")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Pharmacy Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.total.code, "USD")
        self.assertEqual(inst.total.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.total.value, 155.0)
        self.assertEqual(inst.type.coding[0].code, "pharmacy")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")
    
    def testClaim10(self):
        inst = self.instantiate_from("claim-example-pharmacy-medication.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim10(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim10(inst2)
    
    def implClaim10(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code, "654456")
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(inst.id, "760151")
        self.assertEqual(inst.identifier[0].system, "http://happypharma.com/claim")
        self.assertEqual(inst.identifier[0].value, "7612345")
        self.assertEqual(inst.information[0].category.coding[0].code, "pharmacyrefill")
        self.assertEqual(inst.information[0].code.coding[0].code, "new")
        self.assertEqual(inst.information[0].code.coding[0].system, "http://hl7.org/fhir/pharmacy-refill")
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[1].category.coding[0].code, "pharmacyinformation")
        self.assertEqual(inst.information[1].code.coding[0].code, "refillsremaining")
        self.assertEqual(inst.information[1].code.coding[0].system, "http://hl7.org/fhir/pharmacy-information")
        self.assertEqual(inst.information[1].sequence, 2)
        self.assertEqual(inst.information[1].valueQuantity.value, 2)
        self.assertEqual(inst.information[2].category.coding[0].code, "pharmacyinformation")
        self.assertEqual(inst.information[2].code.coding[0].code, "dayssupply")
        self.assertEqual(inst.information[2].code.coding[0].system, "http://hl7.org/fhir/pharmacy-information")
        self.assertEqual(inst.information[2].sequence, 3)
        self.assertEqual(inst.information[2].valueQuantity.value, 90)
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].detail[0].net.code, "USD")
        self.assertEqual(inst.item[0].detail[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[0].net.value, 45.0)
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(inst.item[0].detail[0].service.coding[0].code, "drugcost")
        self.assertEqual(inst.item[0].detail[0].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[1].net.code, "USD")
        self.assertEqual(inst.item[0].detail[1].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[1].net.value, 9.0)
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(inst.item[0].detail[1].service.coding[0].code, "markup")
        self.assertEqual(inst.item[0].detail[1].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].detail[2].net.code, "USD")
        self.assertEqual(inst.item[0].detail[2].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].detail[2].net.value, 36.0)
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(inst.item[0].detail[2].service.coding[0].code, "dispensefee")
        self.assertEqual(inst.item[0].detail[2].service.coding[0].system, "http://hl7.org/fhir/ex-pharmaservice")
        self.assertEqual(inst.item[0].informationLinkId[0], 1)
        self.assertEqual(inst.item[0].informationLinkId[1], 2)
        self.assertEqual(inst.item[0].informationLinkId[2], 3)
        self.assertEqual(inst.item[0].net.code, "USD")
        self.assertEqual(inst.item[0].net.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.item[0].net.value, 90.0)
        self.assertEqual(inst.item[0].quantity.code, "TAB")
        self.assertEqual(inst.item[0].quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.item[0].quantity.unit, "TAB")
        self.assertEqual(inst.item[0].quantity.value, 90)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(inst.item[0].service.coding[0].code, "562721")
        self.assertEqual(inst.item[0].service.coding[0].display, "Alprazolam 0.25mg (Xanax)")
        self.assertEqual(inst.item[0].service.coding[0].system, "http://hl7.org/fhir/RxNorm")
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(inst.payee.type.coding[0].code, "provider")
        self.assertEqual(inst.priority.coding[0].code, "stat")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.div, "<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Pharmacy Claim</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.total.code, "USD")
        self.assertEqual(inst.total.system, "urn:iso:std:iso:4217")
        self.assertEqual(inst.total.value, 90.0)
        self.assertEqual(inst.type.coding[0].code, "pharmacy")
        self.assertEqual(inst.type.coding[0].system, "http://hl7.org/fhir/ex-claimtype")
        self.assertEqual(inst.use, "complete")

